@@ -4,6 +4,6 @@ __uri__ = "https://simmer.readthedocs.io"
 __author__ = "Arjun B. Savel, Lea Hirsch, Courtney D. Dressing, David R. Ciardi"
 __email__ = "asavel@gmail.com"
 __license__ = "MIT"
-__version__ = "0.4.4"
-__release__ = "0.4.4-beta"
+__version__ = "1.0.1"
+__release__ = "1.0.1"
 __description__ = "Stellar Image Maturation via Efficient Reduction"
