@@ -35,8 +35,13 @@ def add_dark_exp(inst, log, raw_dir, tab=None):
             :file: (string) name of file of interest.
         """
         if file[1] == "0":
-            number = literal_eval(file[2:5])  # just a safer eval
-        number = literal_eval(file[1:5])
+            #check below needed because python raises an invalid token error when numbers have leading zeros
+            if file[2] == "0":
+                number = literal_eval(file[3:5])  # just a safer eval
+            else:
+                number = literal_eval(file[2:5])  # just a safer eval
+        else:
+            number = literal_eval(file[1:5])
         return number
 
     def find_end(column):
@@ -55,7 +60,7 @@ def add_dark_exp(inst, log, raw_dir, tab=None):
         end = len(column)
         return end
 
-    def log_to_csv(log, tab, end, new_frame):
+    def log_to_csv(log, tab, end, dark_log):
         """Writes a log to a csv file in current directory.
 
         Inputs:
@@ -69,13 +74,25 @@ def add_dark_exp(inst, log, raw_dir, tab=None):
             writer = pd.ExcelWriter(log, engine="openpyxl")
             writer.book = book
             writer.sheets = dict((ws.title, ws) for ws in book.worksheets)
-            new_frame.to_excel(
+            dark_log.to_excel(
                 writer, tab, index=False, startrow=end, header=False
             )
             writer.save()
+            writer.close()
+
         else:
-            os.remove(log)
-            new_frame.to_csv(log)
+            #Save log with darks to a new file so that we don't end up adding
+            #darks over and over if we rerun the pipeline
+            parts = log.split('.')
+            outlog = parts[0] + '_with_darks.'+parts[-1]
+            current_log = pd.read_csv(log)
+
+            #add the darks to the end of the data frame
+            full_log = current_log.append(dark_log, ignore_index=True)
+            full_log.to_csv(outlog, index=False, header=True)
+            return outlog
+
+
 
     find_itimes(inst, raw_dir)
     if tab:
@@ -101,8 +118,10 @@ def add_dark_exp(inst, log, raw_dir, tab=None):
     exptime = []
     exposes = []
 
+    previous_itime = np.nan #setting to a value that can't possibly match a real exposure time.
     for i, (itime, file) in enumerate(zip(itimes, files)):
-        if itime not in exptime:
+        if itime != previous_itime:
+            previous_itime = itime
             exptime += [itime]
             starts += [get_number(file)]
             objects += ["dark"]
@@ -114,29 +133,58 @@ def add_dark_exp(inst, log, raw_dir, tab=None):
     ends += [get_number(end_file)]
     exposes += [get_number(end_file) - starts[len(starts) - 1] + 1]
 
+
+    #comment some of these out; when frame is merged with an existing log,
+    #any missing columns should be filled in. NOTE: This probably breaks the excel version,
+    #but works for the csv version.
     data_dict = {
         "Object": objects,
         "Start": starts,
         "End": ends,
         "ExpTime": exptime,
-        "Coadds": np.full(len(objects), np.nan),
+
+        "Coadds": np.full(len(objects), 1),
         "Expose": exposes,
-        "Total_tint": np.full(len(objects), np.nan),
-        "Filter": np.full(len(objects), np.nan),
-        """Dither (")""": np.full(len(objects), np.nan),
-        "Aperture": np.full(len(objects), np.nan),
-        "TUB": np.full(len(objects), np.nan),
-        "Airmass": np.full(len(objects), np.nan),
-        "PT": np.full(len(objects), np.nan),
-        "KepMag": np.full(len(objects), np.nan),
-        "Companion": np.full(len(objects), np.nan),
-        "Comments": np.full(len(objects), np.nan),
+        #"Total_tint": np.full(len(objects), np.nan),
+        #"Filter": np.full(len(objects), np.nan),
+        #"""Dither (")""": np.full(len(objects), np.nan),
+        #"Aperture": np.full(len(objects), np.nan),
+        #"TUB": np.full(len(objects), np.nan),
+        #"Airmass": np.full(len(objects), np.nan),
+        #"PT": np.full(len(objects), np.nan),
+        #"KepMag": np.full(len(objects), np.nan),
+        #"Companion": np.full(len(objects), np.nan),
+        #"Comments": np.full(len(objects), np.nan),
+
     }
+
+    # if these columns aren't added, .xlsx files will break here!
+    if log[-3:] != "csv":
+        keys_to_add = [
+            "Coadds",
+            "Total_tint",
+            "Filter",
+            """Dither (")""",
+            "Aperture",
+            "TUB",
+            "Airmass",
+            "PT",
+            "KepMag",
+            "Companion",
+            "Comments",
+        ]
+        for key in keys_to_add:
+            data_dict[key] = np.full(len(objects), np.nan)
+
     new_frame = pd.DataFrame(data=data_dict)
 
     end = find_end(initial_frame["Object"])
 
-    log_to_csv(log, tab, end, new_frame)
+
+    outlog = log_to_csv(log, tab, end, new_frame)
+
+    return outlog
+
 
 
 def find_itimes(inst, raw_dir):
@@ -165,12 +213,12 @@ def find_itimes(inst, raw_dir):
             if np.logical_and(
                 len(hkeys[integrations]) > 0, len(hkeys[objects]) > 0
             ):
-                itime = int(round(inst.itime(head)))
                 obj = head["OBJECT  "]
 
                 if obj == "dark":
                     #                     if lastitime != itime:
                     #                         lastitime = itime
+                    itime = float(round(inst.itime(head),2))
                     outfile.write(
                         os.path.basename(file) + " " + str(itime) + "\n"
                     )
