@@ -9,10 +9,6 @@ from tqdm import tqdm
 from . import plotting as pl
 from . import utils as u
 
-CENTER = (750, 1100)  # row,col
-NPIX = 600
-
-
 def dark_driver(raw_dir, reddir, config, inst, plotting_yml=None):
     """Night should be entered in format 'yyyy_mm_dd' as string.
     This will point toward a config file for the night with darks listed.flat
@@ -71,10 +67,7 @@ def create_darks(raw_dir, reddir, darklist, inst):
         f"dark_cube_{int(round(itime))}sec.png",
     )
 
-    # CDD update
-    # head.update('DATAFILE', str(darklist)) #add all file names
     head.set("DATAFILE", str(darklist))  # add all file names
-    # end CDD update
 
     hdu = pyfits.PrimaryHDU(
         final_dark, header=head
