@@ -8,15 +8,12 @@ from glob import glob
 import astropy.io.fits as pyfits
 import numpy as np
 from tqdm import tqdm
+import re as re
 
 from . import plotting as pl
 from . import utils as u
 
-CENTER = (750, 1100)  # row,col
-NPIX = 600
-
-
-def sky_driver(raw_dir, reddir, config, inst, plotting_yml=None):
+def sky_driver(raw_dir, reddir, config, inst, sep_skies = False, plotting_yml=None):
     """Night should be entered in format 'yyyy_mm_dd' as string.
     This will point toward a config file for the night with flats listed.
 
@@ -25,6 +22,7 @@ def sky_driver(raw_dir, reddir, config, inst, plotting_yml=None):
         :reddir: (string) directory for the reduced data
         :config: (pandas DataFrame) dataframe corresponding to config sheet for data.
         :inst: (Instrument object) instrument for which data is being reduced.
+        :sep_skies: (Boolean) if true, skies for observations of star STAR are recorded with Object = "STAR sky". If false, observations were taken using a dither pattern and can be used as the skies.
         :plotting_yml: (string) path to the plotting configuration file.
     """
 
@@ -40,28 +38,47 @@ def sky_driver(raw_dir, reddir, config, inst, plotting_yml=None):
     stars = skies.Object.unique()
     sdirs = glob(reddir + "*/")
 
+    #Split into sky frames and star frames for observations taken by nodding
+    if sep_skies == True:
+        keep = np.zeros(len(stars)) + 1
+        for kk in np.arange(len(keep)):
+            if("sky" in stars[kk]):
+                keep[kk] = 0
+
+        wsky = np.where(keep == 0)
+        wstar = np.where(keep == 1)
+        skynames = stars[wsky]
+        starnames = stars[wstar]
+
+    else:
+        starnames = stars
+        skynames = stars
+
     if plotting_yml:
         pl.initialize_plotting(plotting_yml)
 
-    for star in tqdm(stars, desc="Running skies", position=0, leave=True):
-
-        s_dir = reddir + star + "/"
+    for starname in tqdm(starnames, desc="Running skies", position=0, leave=True):
+        s_dir = reddir + starname + "/"
         if (
             s_dir not in sdirs
         ):  # make sure there's a subdirectory for each star
             os.mkdir(s_dir)
 
+        #determine object name for skies
+        if sep_skies == True:
+            skyname = starname+' sky'
+        else:
+            skyname = starname
+
         filts = skies[
-            skies.Object == star
+            skies.Object == skyname
         ].Filter.values  # array of filters as strings
+
         for n, filter_name in enumerate(filts):
-            # CDD change
-            # skylist = literal_eval(skies[skies.Object == s].Filenums.values[n])
-            # literal_eval issues below
             skylist = eval(
-                skies[skies.Object == star].Filenums.values[n]
-            )  # pylint: disable=eval-used
-            # end CDD change
+
+                skies[skies.Object == skyname].Filenums.values[n]
+            )
             create_skies(
                 raw_dir, reddir, s_dir, skylist, inst, filter_name=filter_name
             )
@@ -107,6 +124,17 @@ def create_skies(
     flatfile = reddir + f"flat_{filt}.fits"
     if inst.name == "PHARO" and filt == "Br-gamma":
         flatfile = reddir + "flat_K_short.fits"  # no BrG flats in Palomar data
+
+    #For ShARCS, use Ks flat instead of BrG-2.16 if necessary
+    if (inst.name == "ShARCS" and filt == "BrG-2.16"):
+        if os.path.exists(flatfile) == False:
+            flatfile = reddir + 'flat_Ks.fits'
+
+    #For ShARCS, use J flat instead of J+Ch4-1.2 if necessary
+    if (inst.name == "ShARCS" and filt == "J+Ch4-1.2"):
+        if os.path.exists(flatfile) == False:
+            flatfile = reddir + 'flat_J.fits'
+
     flat = pyfits.getdata(flatfile, 0)
 
     for i in range(nskies):
@@ -119,10 +147,8 @@ def create_skies(
     pl.plot_array(
         "intermediate", sky_array, -10.0, 100.0, sf_dir, "sky_cube.png"
     )
-    # CDD change
-    #  head.update('DATAFILE', str(skylist)) #add all file names
+
     head.set("DATAFILE", str(skylist))  # add all file names
-    # end CDD change
 
     hdu = pyfits.PrimaryHDU(final_sky, header=head)
     hdu.writeto(sf_dir + "sky.fits", overwrite=True, output_verify="ignore")
